import { getNoOfIOCs, isBatchJob } from "./JobUtils";
import {
  EllipsisText,
  InternalLink,
  Table,
  SimpleAccordion
} from "@ess-ics/ce-ui-common";
import { Typography, Stack } from "@mui/material";
import { JobRevisionChip } from "./JobRevisionChip";

const columns = [
  {
    field: "ioc",
    headerName: "IOC"
  },
  {
    field: "revision",
    headerName: "Revision"
  },
  {
    field: "host",
    headerName: "Host"
  }
];

const calculateHostText = (job) => {
  // host is resolvable => show link for users
  if (job?.host?.hostId && job?.host?.externalIdValid) {
    return (
      <InternalLink
        to={`/hosts/${job.host.hostId}`}
        label={`Host Details, ${job.host.fqdn}`}
        width="100%"
      >
        <EllipsisText>{job.host.fqdn}</EllipsisText>
      </InternalLink>
    );
  }
  // gray out hostname if it is from cache
  return (
    <Typography color="gray">
      <EllipsisText>{job?.host?.fqdn}</EllipsisText>
    </Typography>
  );
};

const createRow = (job) => {
  const shapedHostName = calculateHostText(job);
  return {
    id: job.id,
    ioc: (
      <InternalLink
        to={`/iocs/${job.iocId}`}
        label={`Ioc details, ${job.iocName}`}
        width="100%"
      >
        <EllipsisText>{job.iocName}</EllipsisText>
      </InternalLink>
    ),
    host: shapedHostName,
    revision: (
      <JobRevisionChip
        gitReference={job.gitReference}
        gitProjectId={job.gitProjectId}
      />
    )
  };
};

const shapeBatchRows = (jobs) =>
  jobs.reduce((accumulator, job) => {
    const ioc = job.iocs.reduce((iocsAccumulator, ioc) => {
      return [...iocsAccumulator, { ...{ host: job.host, ...ioc } }];
    }, []);
    return [...accumulator, ...ioc];
  }, []);

export const JobDetailsTable = ({ operation }) => (
  <>
    {isBatchJob(operation.type) ? (
      <SimpleAccordion
        summary={
          <Stack
            flexDirection="row"
            alignItems="end"
            sx={{ width: "100%" }}
            gap={1}
          >
            {" "}
            <Typography
              component="h2"
              variant="h3"
            >
              Batch
            </Typography>
            <Typography
              variant="body2"
              sx={{ fontWeight: "600", marginRight: "10px" }}
            >
              {getNoOfIOCs(operation.jobs)} IOCs, {operation.jobs.length} Hosts
            </Typography>
          </Stack>
        }
      >
        <Table
          columns={columns}
          rows={shapeBatchRows(operation.jobs).map((job) => createRow(job))}
        />
      </SimpleAccordion>
    ) : (
      <Table
        columns={columns}
        rows={[operation].map((job) => createRow(job))}
      />
    )}
  </>
);
