import { useCallback, useContext, useEffect } from "react";
import { Card, CardHeader } from "@mui/material";
import { initRequestParams } from "../Helper";
import { JobTable } from "../../Job";
import { apiContext } from "../../../api/DeployApi";
import { useAPIMethod, usePagination, usePolling } from "@ess-ics/ce-ui-common";
import { ROWS_PER_PAGE } from "../../../constants";

export function UserOperationList({ userName }) {
  const client = useContext(apiContext);

  const {
    value: jobs,
    wrapper: getJobs,
    loading,
    dataReady,
    abort
  } = useAPIMethod({
    fcn: client.apis.Jobs.listJobs,
    call: false
  });

  const { pagination, setPagination } = usePagination({
    rowsPerPageOptions: ROWS_PER_PAGE,
    initLimit: ROWS_PER_PAGE[0],
    initPage: 0
  });

  // update pagination whenever search result total pages change
  useEffect(() => {
    setPagination({ totalCount: jobs?.totalCount ?? 0 });
  }, [setPagination, jobs?.totalCount]);

  const callGetjobs = useCallback(() => {
    let requestParams = initRequestParams(pagination);

    requestParams.user = userName;

    getJobs(requestParams);
  }, [getJobs, pagination, userName]);

  useEffect(() => {
    callGetjobs();

    return () => {
      abort();
    };
  }, [callGetjobs, abort]);

  usePolling(callGetjobs, loading, 30000, abort);

  // Invoked by Table on change to pagination
  const onPage = (params) => {
    setPagination(params);
    abort();
  };

  return (
    <Card variant="plain">
      <CardHeader
        title={"Operations"}
        titleTypographyProps={{
          variant: "h2",
          component: "h2"
        }}
      />
      <JobTable
        jobs={jobs?.jobs}
        customColumns={[{ field: "status" }, { field: "job" }]}
        loading={loading || !dataReady}
        pagination={pagination}
        onPage={onPage}
        rowType="userPageJobLog"
      />
    </Card>
  );
}
