import { useContext, useMemo, useEffect } from "react";
import { apiContext } from "../../../api/DeployApi";
import { useAPIMethod } from "@ess-ics/ce-ui-common";
import { getHostStatus } from "./HostStatusData";
import { Status } from "../../common/Status";

function createRequest(hostId) {
  return {
    host_id: hostId
  };
}

export const HostStatus = ({ hostId, hideAlerts }) => {
  const client = useContext(apiContext);
  const params = useMemo(() => createRequest(hostId), [hostId]);

  const {
    wrapper: callFetchHostAlerts,
    value: hostAlert,
    abort: abortCallFetchHostAlerts
  } = useAPIMethod({
    fcn: client.apis.Hosts.findHostAlerts,
    params,
    call: false
  });

  const { value: hostStateStatus } = useAPIMethod({
    fcn: client.apis.Hosts.findHostStatus,
    params
  });

  useEffect(() => {
    if (!hideAlerts) {
      callFetchHostAlerts();
    }

    return () => {
      abortCallFetchHostAlerts();
    };
  }, [hideAlerts, callFetchHostAlerts, abortCallFetchHostAlerts]);

  return (
    <>
      {hostStateStatus && (
        <Status
          id={hostStateStatus.hostId}
          state={hostStateStatus}
          alert={hostAlert}
          hideAlerts={hideAlerts}
          getStatusFcn={getHostStatus}
        />
      )}
    </>
  );
};
