import { useEffect, useContext, useState, useMemo } from "react";
import { IOCDetailsView } from "./IOCDetailsView";
import { LinearProgress } from "@mui/material";
import NotFoundView from "../../components/navigation/NotFoundView/NotFoundView";
import { onFetchEntityError } from "../../components/common/Helper";
import { useAPIMethod } from "@ess-ics/ce-ui-common";
import { apiContext } from "../../api/DeployApi";

export function IOCDetailsContainer({ id }) {
  const [error, setError] = useState(null);

  const client = useContext(apiContext);

  const params = useMemo(
    () => ({
      ioc_id: id
    }),
    [id]
  );

  const {
    value: ioc,
    wrapper: getIOC,
    loading,
    error: fetchError,
    abort: abortGetIOC
  } = useAPIMethod({
    fcn: client.apis.IOCs.getIoc,
    params
  });

  useEffect(() => {
    if (fetchError) {
      onFetchEntityError(fetchError?.message, fetchError?.status, setError);
    }
  }, [fetchError]);

  if (error) {
    return (
      <NotFoundView
        message={error?.message}
        status={error?.status}
      />
    );
  }

  if (!ioc && !error) {
    return <LinearProgress color="primary" />;
  }

  return (
    <IOCDetailsView
      ioc={ioc}
      getIOC={getIOC}
      abortGetIOC={abortGetIOC}
      loading={loading}
    />
  );
}
