import { useState, useMemo, useContext, useEffect } from "react";
import { HostDetailsView } from "./HostDetailsView";
import { LinearProgress } from "@mui/material";
import { onFetchEntityError } from "../../../components/common/Helper";
import NotFoundView from "../../../components/navigation/NotFoundView/NotFoundView";
import { apiContext } from "../../../api/DeployApi";
import { useAPIMethod } from "@ess-ics/ce-ui-common";

export function HostDetailsContainer({ hostId }) {
  const [error, setError] = useState(null);
  const client = useContext(apiContext);

  const alertParams = useMemo(
    () => ({
      host_id: hostId
    }),
    [hostId]
  );

  const hostParams = useMemo(
    () => ({
      host_id: hostId
    }),
    [hostId]
  );

  const { value: host, error: fetchError } = useAPIMethod({
    fcn: client.apis.Hosts.findNetBoxHostByHostId,
    params: hostParams
  });

  const { value: alert, error: alertError } = useAPIMethod({
    fcn: client.apis.Hosts.findHostAlerts,
    params: alertParams
  });

  useEffect(() => {
    if (fetchError || alertError) {
      const message = fetchError?.message
        ? fetchError.message
        : alertError.message;
      const status = fetchError?.status
        ? fetchError.status
        : alertError?.status;
      onFetchEntityError(message, status, setError);
    }
  }, [fetchError, alertError]);

  if (error) {
    return (
      <NotFoundView
        message={error?.message}
        status={error?.status}
      />
    );
  }

  if (!host || !alert) {
    return <LinearProgress color="primary" />;
  }

  return (
    <HostDetailsView
      host={host}
      alert={alert}
      hostId={hostId}
    />
  );
}
