import { useEffect, useContext, useCallback } from "react";
import IOCTable from "../../../components/IOC/IOCTable";
import { string } from "prop-types";
import { apiContext } from "../../../api/DeployApi";
import { Typography } from "@mui/material";
import { useAPIMethod, usePagination } from "@ess-ics/ce-ui-common";
import { initRequestParams } from "../../../components/common/Helper";
import { ROWS_PER_PAGE } from "../../../constants";

const propTypes = {
  hostId: string
};

export const HostIocSection = ({ hostId }) => {
  const client = useContext(apiContext);

  const { pagination, setPagination, setTotalCount } = usePagination({
    initLimit: ROWS_PER_PAGE[0],
    initPage: 0
  });

  const {
    value: iocs,
    wrapper: callgetIocs,
    loading,
    dataReady,
    abort: abortGetIocs
  } = useAPIMethod({
    fcn: client.apis.Hosts.findAssociatedIocsByHostId,
    call: false
  });

  const onPage = useCallback(
    (params) => {
      setPagination(params);
      abortGetIocs();
    },
    [setPagination, abortGetIocs]
  );

  const getIocs = useCallback(() => {
    let requestParams = initRequestParams(pagination, null);
    requestParams.host_id = hostId;
    callgetIocs(requestParams);
  }, [callgetIocs, hostId, pagination]);

  // update pagination whenever search result total pages change
  useEffect(() => {
    setTotalCount(iocs?.totalCount ?? 0);
  }, [setTotalCount, iocs?.totalCount]);

  useEffect(() => {
    getIocs();

    return () => {
      abortGetIocs();
    };
  }, [abortGetIocs, getIocs]);

  return (
    <>
      <Typography
        variant="h3"
        component="h2"
      >
        IOCs
      </Typography>
      <IOCTable
        iocs={iocs?.deployedIocs || []}
        loading={loading || !dataReady}
        rowType="host"
        pagination={pagination}
        onPage={onPage}
      />
    </>
  );
};

HostIocSection.propTypes = propTypes;
